@@ -73,30 +73,31 @@ public class SHTMLPanelImpl extends SHTMLPanel implements CaretListener {
     /** single instance of a dynamic resource for use by all */
     public DynamicResource dynRes = new DynamicResource();
     /** SimplyHTML's main resource bundle (plug-ins use their own) */
-    private static TextResources textResources = null;
+    private static UIResources uiResources = null;
 
-    public static TextResources getResources() {
-        if (textResources == null) {
-            textResources = SHTMLPanelImpl.readDefaultResources();
+    public static UIResources getUiResources() {
+        if (uiResources == null) {
+        	setInternalUiResources();
         }
-        return textResources;
+        return uiResources;
     }
 
     /** the plug-in manager of SimplyHTML */
     public static PluginManager pluginManager; // = new PluginManager(mainFrame);
     protected ActionListener openHyperlinkHandler = null;
 
-    public static void setTextResources(final TextResources textResources) {
-        if (SHTMLPanelImpl.textResources != null) {
-            return;
-        }
-        SHTMLPanelImpl.textResources = textResources != null ? textResources : SHTMLPanelImpl.readDefaultResources();
+    public static void setUiResources(final UIResources uiResources) {
+        SHTMLPanelImpl.uiResources = uiResources;
     }
 
-    private static TextResources readDefaultResources() {
+    public static void setInternalUiResources() {
+        SHTMLPanelImpl.uiResources = SHTMLPanelImpl.readDefaultResources();
+    }
+
+    private static UIResources readDefaultResources() {
         try {
-            final String propsLoc = "com/lightdev/app/shtm/resources/SimplyHTML_common.properties";
-            final URL defaultPropsURL = ClassLoader.getSystemResource(propsLoc);
+            final String propsLoc = "/com/lightdev/app/shtm/resources/SimplyHTML_common.properties";
+            final URL defaultPropsURL = SHTMLPanelImpl.class.getResource(propsLoc);
             final Properties props = new Properties();
             InputStream in = null;
             in = defaultPropsURL.openStream();
@@ -104,7 +105,7 @@ public class SHTMLPanelImpl extends SHTMLPanel implements CaretListener {
             in.close();
             final ResourceBundle resourceBundle = ResourceBundle.getBundle(
                 "com.lightdev.app.shtm.resources.SimplyHTML", Locale.getDefault());
-            return new DefaultTextResources(resourceBundle, props);
+            return new InternalUiResources(resourceBundle, props);
         }
         catch (final Exception ex) {
             Util.errMsg(null, "resources not found", ex);
@@ -242,8 +243,8 @@ public class SHTMLPanelImpl extends SHTMLPanel implements CaretListener {
         initActions();
         if(actionBuilder != null)
         	actionBuilder.initActions(this);
-        menuBar = dynRes.createMenubar(textResources, "menubar");
-        editorPopup = dynRes.createPopupMenu(textResources, "popup");
+        menuBar = dynRes.createMenubar(uiResources, "menubar");
+        editorPopup = dynRes.createPopupMenu(uiResources, "popup");
         setJMenuBar(menuBar);
         customizeFrame();
         initAppTempDir();
@@ -268,8 +269,8 @@ public class SHTMLPanelImpl extends SHTMLPanel implements CaretListener {
         return menuBar.handleKeyBinding(ks, e, condition, pressed);
     }
 
-    public JMenuItem newActionMenuItem(final String actionName) {
-        return dynRes.createMenuItem(SHTMLPanelImpl.getResources(), actionName);
+    public JMenuItem createActionMenuItem(final String actionName) {
+        return dynRes.createMenuItem(SHTMLPanelImpl.getUiResources(), actionName);
     }
 
     public Action getAction(final String actionName) {
@@ -592,7 +593,7 @@ public class SHTMLPanelImpl extends SHTMLPanel implements CaretListener {
             if (pluginMenu != null) {
                 Icon menuIcon = pluginMenu.getIcon();
                 if (menuIcon == null) {
-                    final URL url = DynamicResource.getResource(textResources, emptyIcon);
+                    final URL url = DynamicResource.getResource(uiResources, emptyIcon);
                     if (url != null) {
                         menuIcon = new ImageIcon(url);
                         pluginMenu.setIcon(new ImageIcon(url));
@@ -605,7 +606,7 @@ public class SHTMLPanelImpl extends SHTMLPanel implements CaretListener {
                 if (helpMenu.getSubElements().length > 0) {
                     Icon menuIcon = helpMenu.getIcon();
                     if (menuIcon == null) {
-                        final URL url = DynamicResource.getResource(textResources, emptyIcon);
+                        final URL url = DynamicResource.getResource(uiResources, emptyIcon);
                         if (url != null) {
                             menuIcon = new ImageIcon(url);
                             helpMenu.setIcon(new ImageIcon(url));
@@ -877,9 +878,8 @@ public class SHTMLPanelImpl extends SHTMLPanel implements CaretListener {
      * @return the created tool bar
      */
     JToolBar createToolBar(final String nm) {
-        final String[] itemKeys = Util.tokenize(Util.getResourceString(textResources, nm), " ");
+        final String[] itemKeys = Util.tokenize(Util.getResourceString(uiResources, nm), " ");
         final JToolBar toolBar = new JToolBar();
-        toolBar.putClientProperty("JToolBar.isRollover", Boolean.TRUE);
         for (int i = 0; i < itemKeys.length; i++) {
             /** special handling for separators */
             final String itemKey = itemKeys[i];
@@ -889,14 +889,9 @@ public class SHTMLPanelImpl extends SHTMLPanel implements CaretListener {
     }
 
     protected void createToolbarItem(final JToolBar toolBar, final String itemKey) {
-        final ToggleBorderListener tbl = new ToggleBorderListener();
-        final Dimension buttonSize = new Dimension(24, 24);
-        final Dimension comboBoxSize = new Dimension(300, 24);
-        final Dimension separatorSize = new Dimension(3, 24);
         JSeparator separator;
         if (itemKey.equals(DynamicResource.menuSeparatorKey)) {
             separator = new JSeparator(JSeparator.VERTICAL);
-            separator.setMaximumSize(separatorSize);
             toolBar.add(separator);
         }
         /**
@@ -905,16 +900,13 @@ public class SHTMLPanelImpl extends SHTMLPanel implements CaretListener {
          */
         else if (itemKey.equalsIgnoreCase(fontFamilyAction)) {
             final FontFamilyPicker fontFamily = new FontFamilyPicker();
-            fontFamily.setPreferredSize(new Dimension(180, 23));
             fontFamily.setAction(dynRes.getAction(fontFamilyAction));
-            fontFamily.setMaximumSize(comboBoxSize);
             toolBar.add(fontFamily);
         }
         else if (itemKey.equalsIgnoreCase(fontSizeAction)) {
             final FontSizePicker fontSize = new FontSizePicker();
-            fontSize.setPreferredSize(new Dimension(50, 23));
+            fontSize.setPrototypeDisplayValue("88888");
             fontSize.setAction(dynRes.getAction(fontSizeAction));
-            fontSize.setMaximumSize(comboBoxSize);
             toolBar.add(fontSize);
         }
         else if (itemKey.equalsIgnoreCase(setTagAction)) {
@@ -935,7 +927,7 @@ public class SHTMLPanelImpl extends SHTMLPanel implements CaretListener {
                 if (itemKey.equalsIgnoreCase(helpTopicsAction)) {
                     newButton = SHTMLHelpBroker.createHelpButton("item15");
                     final Icon icon = DynamicResource
-                        .getIconForCommand(SHTMLPanelImpl.getResources(), helpTopicsAction);
+                        .getIconForCommand(SHTMLPanelImpl.getUiResources(), helpTopicsAction);
                     newButton.setIcon(icon);
                     newButton.setToolTipText(Util.getResourceString(helpTopicsAction + DynamicResource.toolTipSuffix));
                     toolBar.add(newButton);
@@ -946,22 +938,10 @@ public class SHTMLPanelImpl extends SHTMLPanel implements CaretListener {
                      */
                     final Action action = dynRes.getAction(itemKey);
                     if (action instanceof AttributeComponent) {
-                        newButton = new JToggleButton("", (Icon) action.getValue(Action.SMALL_ICON));
-                        newButton.addMouseListener(tbl);
-                        newButton.setAction(action);
+                        newButton = new JToggleButton(action);
                         newButton.setText("");
-                        //newButton.setActionCommand("");
-                        newButton.setBorderPainted(false);
+                        newButton.setHideActionText(true);
                         action.addPropertyChangeListener(new ToggleActionChangedListener((JToggleButton) newButton));
-                        final Icon si = DynamicResource.getIconForName(textResources, action.getValue(Action.NAME)
-                                + DynamicResource.selectedIconSuffix);
-                        if (si != null) {
-                            newButton.setSelectedIcon(si);
-                        }
-                        newButton.setMargin(new Insets(0, 0, 0, 0));
-                        newButton.setIconTextGap(0);
-                        newButton.setContentAreaFilled(false);
-                        newButton.setHorizontalAlignment(SwingConstants.CENTER);
                         newButton.setVerticalAlignment(SwingConstants.CENTER);
                         toolBar.add(newButton);
                     }
@@ -972,11 +952,6 @@ public class SHTMLPanelImpl extends SHTMLPanel implements CaretListener {
                         newButton = toolBar.add(action);
                     }
                 }
-                newButton.setMinimumSize(buttonSize);
-                newButton.setPreferredSize(buttonSize);
-                newButton.setMaximumSize(buttonSize);
-                newButton.setFocusPainted(false);
-                newButton.setRequestFocusEnabled(false);
                 if (System.getProperty("os.name").equals("Mac OS X")) {
                     newButton.putClientProperty("JButton.buttonType", "segmented");
                     newButton.putClientProperty("JButton.segmentPosition", "middle");
@@ -989,41 +964,6 @@ public class SHTMLPanelImpl extends SHTMLPanel implements CaretListener {
         }
     }
 
-    /**
-     * displays or removes an etched border around JToggleButtons
-    * this listener is registered with.
-    */
-    private class ToggleBorderListener implements MouseListener {
-        private final EtchedBorder border = new EtchedBorder(EtchedBorder.LOWERED);
-        private JToggleButton button;
-
-        public void mouseClicked(final MouseEvent e) {
-        }
-
-        public void mouseEntered(final MouseEvent e) {
-            final Object src = e.getSource();
-            if (src instanceof JToggleButton) {
-                button = (JToggleButton) src;
-                if (button.isEnabled()) {
-                    ((JToggleButton) src).setBorder(border);
-                }
-            }
-        }
-
-        public void mouseExited(final MouseEvent e) {
-            final Object src = e.getSource();
-            if (src instanceof JToggleButton) {
-                ((JToggleButton) src).setBorder(null);
-            }
-        }
-
-        public void mousePressed(final MouseEvent e) {
-        }
-
-        public void mouseReleased(final MouseEvent e) {
-        }
-    }
-
     /**
      * register FrmMain as an object which has interest
      * in events from a given document pane
@@ -1071,7 +1011,7 @@ public class SHTMLPanelImpl extends SHTMLPanel implements CaretListener {
      * that way, we catch the exception here.
      */
     catch(DocNameMissingException e) {
-      Util.errMsg(this, Util.getResourceString(textResources, "docNameMissingError"), e);
+      Util.errMsg(this, Util.getResourceString(uiResources, "docNameMissingError"), e);
     }
   }
 
@@ -1089,24 +1029,21 @@ public class SHTMLPanelImpl extends SHTMLPanel implements CaretListener {
      * @param action the action to apply properties to
      * @param cmd the name of the action to get properties for
      */
-    public static void getActionProperties(final Action action, final String cmd) {
-        final Icon icon = DynamicResource.getIconForCommand(textResources, cmd);
-        if (icon != null) {
-            action.putValue(Action.SMALL_ICON, icon);
-        }
-        /*else {
-          action.putValue(Action.SMALL_ICON, emptyIcon);
-        }*/
-        final String name = Util.getResourceString(textResources, cmd + DynamicResource.labelSuffix);
+    public static void configureActionProperties(final Action action, final String cmd) {
+        final String name = Util.getResourceString(uiResources, cmd + DynamicResource.labelSuffix);
         if (name != null) {
             action.putValue(Action.NAME, name);
         }
-        final String toolTip = Util.getResourceString(textResources, cmd + DynamicResource.toolTipSuffix);
+        final Icon icon = DynamicResource.getIconForCommand(uiResources, cmd);
+        if (icon != null) {
+            action.putValue(Action.SMALL_ICON, icon);
+        }
+        final String toolTip = Util.getResourceString(uiResources, cmd + DynamicResource.toolTipSuffix);
         if (toolTip != null) {
             action.putValue(Action.SHORT_DESCRIPTION, toolTip);
         }
         
-        final String accelerator = Util.getResourceString(textResources, cmd + DynamicResource.acceleratorSuffix);
+        final String accelerator = Util.getResourceString(uiResources, cmd + DynamicResource.acceleratorSuffix);
         if (accelerator != null) {
             action.putValue(Action.ACCELERATOR_KEY, KeyStroke.getKeyStroke(accelerator));
         }
